==> xs2a-impl-4.1-sources.jar: de/adorsys/psd2/xs2a/web/validator/body/raw/PaymentRawBodyValidatorImpl.java <==
/*
 * Copyright 2018-2019 adorsys GmbH & Co KG
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.adorsys.psd2.xs2a.web.validator.body.raw;

import de.adorsys.psd2.xs2a.exception.MessageError;
import de.adorsys.psd2.xs2a.web.validator.body.DateFieldValidator;
import org.springframework.stereotype.Component;

import javax.servlet.http.HttpServletRequest;

import static de.adorsys.psd2.xs2a.web.validator.constants.Xs2aRequestBodyDateFields.PAYMENT_DATE_FIELDS;

@Component
public class PaymentRawBodyValidatorImpl implements PaymentRawBodyValidator {

    private DateFieldValidator dateFieldValidator;

    protected PaymentRawBodyValidatorImpl(DateFieldValidator dateFieldValidator) {
        this.dateFieldValidator = dateFieldValidator;
    }

    @Override
    public void validate(HttpServletRequest request, MessageError messageError) {
        dateFieldValidator.validateDayOfExecution(request, messageError);
        dateFieldValidator.validateRawDataDates(request, PAYMENT_DATE_FIELDS.getDateFields(), messageError);
    }
}

==> xs2a-impl-4.9-sources.jar: de/adorsys/psd2/xs2a/web/validator/body/raw/PaymentRawBodyValidatorImpl.java <==
/*
 * Copyright 2018-2019 adorsys GmbH & Co KG
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.adorsys.psd2.xs2a.web.validator.body.raw;

import de.adorsys.psd2.xs2a.exception.MessageError;
import de.adorsys.psd2.xs2a.web.validator.body.DateFieldValidator;
import org.springframework.stereotype.Component;

import javax.servlet.http.HttpServletRequest;

import static de.adorsys.psd2.xs2a.web.validator.constants.Xs2aRequestBodyDateFields.PAYMENT_DATE_FIELDS;

@Component
public class PaymentRawBodyValidatorImpl implements PaymentRawBodyValidator {

    private DateFieldValidator dateFieldValidator;

    protected PaymentRawBodyValidatorImpl(DateFieldValidator dateFieldValidator) {
        this.dateFieldValidator = dateFieldValidator;
    }

    @Override
    public MessageError validate(HttpServletRequest request, MessageError messageError) {
        dateFieldValidator.validateDayOfExecution(request, messageError);
        return dateFieldValidator.validateRawDataDates(request, PAYMENT_DATE_FIELDS.getDateFields(), messageError);
    }
}
